@@ -44,7 +44,7 @@
 #include <qmailmessage.h>
 
 // if VK_LOGING define, then will writes libvkontakte api transfer data
-#define VK_LOGING
+#undef VK_LOGING
 
 #ifdef VK_LOGING
 // Name of file for writing log. Will located in temp directory
@@ -57,6 +57,8 @@
 
 // Name of library that used for connection (without extension)
 #define LIBNAME "libmsavk"
+// Version of library that used for connection
+#define LIBVERSION 0
 
 #define VK_AT '@'
 #define VK_FAKE_ADDRESS "@vk.com"
